==> messagelib-16.07.80.tar.xz: messagelib-16.07.80/messageviewer/src/messagepartthemes/default/messagepartrenderermanager.h <==
/*
   Copyright (c) 2016 Laurent Montel <montel@kde.org>

   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
   the Free Software Foundation; either version 2 of the License, or (at your
   option) any later version.

   This library is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
   License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to the
   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
   02110-1301, USA.
*/

#ifndef MESSAGEPARTRENDERERMANAGER_H
#define MESSAGEPARTRENDERERMANAGER_H

#include <QObject>
#include "messageviewer_export.h"
#include <grantlee/template.h>

namespace GrantleeTheme
{
class Engine;
}

namespace MessageViewer
{

class MESSAGEVIEWER_EXPORT MessagePartRendererManager : public QObject
{
    Q_OBJECT
public:
    explicit MessagePartRendererManager(QObject *parent = Q_NULLPTR);
    ~MessagePartRendererManager();
    static MessagePartRendererManager *self();

    Grantlee::Template loadByName(const QString &name);
    Grantlee::Context createContext();
    int iconCurrentSize() const;
private:
    void initializeRenderer();
    GrantleeTheme::Engine *m_engine;
    int mCurrentIconSize;
};
}

#endif // MESSAGEPARTRENDERERMANAGER_H

==> messagelib-17.08.0.tar.xz: messagelib-17.08.0/messageviewer/src/messagepartthemes/default/messagepartrenderermanager.h <==
/*
   Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>

   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
   the Free Software Foundation; either version 2 of the License, or (at your
   option) any later version.

   This library is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
   License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to the
   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
   02110-1301, USA.
*/

#ifndef MESSAGEPARTRENDERERMANAGER_H
#define MESSAGEPARTRENDERERMANAGER_H

#include <QObject>
#include "messageviewer_export.h"
#include <grantlee/template.h>

namespace GrantleeTheme {
class Engine;
}

namespace MessageViewer {
class MESSAGEVIEWER_EXPORT MessagePartRendererManager : public QObject
{
    Q_OBJECT
public:
    explicit MessagePartRendererManager(QObject *parent = nullptr);
    ~MessagePartRendererManager();
    static MessagePartRendererManager *self();

    Grantlee::Template loadByName(const QString &name);
    Grantlee::Context createContext();
    int iconCurrentSize() const;
private:
    void initializeRenderer();
    GrantleeTheme::Engine *m_engine;
    int mCurrentIconSize;
};
}

#endif // MESSAGEPARTRENDERERMANAGER_H
